==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/midi/src/MIDI_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Konfigurace MIDI Pluginu</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI Kanál</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Inicializační zpráva</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Není</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Tento plugin přidává podporu vstupu/výstupu pro zařízení MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Podpora výstupu není k dispozici.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Otevřený</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Neotevřený</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Chybný výstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Podpora vstupu není k dispozici.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Chybný vstup</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="196"/>
        <source>No error occurred.</source>
        <translation>Nenastal žádný problém.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="198"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Nastala chyba při čtení ze souboru.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="200"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Nastala chyba při zápisu do souboru.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="202"/>
        <source>A fatal error occurred.</source>
        <translation>Nastala závažná chyba.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="204"/>
        <source>Resource error occurred.</source>
        <translation>Chyba zdroje.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="206"/>
        <source>The file could not be opened.</source>
        <translation>Sobor nemohl být otevřen.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="208"/>
        <source>The operation was aborted.</source>
        <translation>Operace se souborem byla přerušena.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="210"/>
        <source>A timeout occurred.</source>
        <translation>Vypršel časový limit.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="212"/>
        <source>An unspecified error occurred.</source>
        <translation>Nastala neznámá chyba.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="214"/>
        <source>The file could not be removed.</source>
        <translation>Soubor se nepodařilo odstranit.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="216"/>
        <source>The file could not be renamed.</source>
        <translation>Soubor se nepodařilo přejmenovat.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="218"/>
        <source>The position in the file could not be changed.</source>
        <translation>Pozice v souboru nemohla být změněna.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="220"/>
        <source>The file could not be resized.</source>
        <translation>Nepodařilo se změnit velikost souboru.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="222"/>
        <source>The file could not be accessed.</source>
        <translation>Nepodařilo se přistoupit k souboru.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="224"/>
        <source>The file could not be copied.</source>
        <translation>Soubor se nedá zkopírovat.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="226"/>
        <source>An unknown error occurred.</source>
        <translation>Nastala neznámá chyba.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/midi/src/MIDI_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Konfigurace MIDI Pluginu</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI Kanál</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Inicializační zpráva</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Není</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Tento plugin přidává podporu vstupu/výstupu pro zařízení MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Podpora výstupu není k dispozici.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Otevřený</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Neotevřený</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Chybný výstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Podpora vstupu není k dispozici.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Chybný vstup</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation>Nenastal žádný problém.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Nastala chyba při čtení ze souboru.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Nastala chyba při zápisu do souboru.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation>Nastala závažná chyba.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation>Chyba zdroje.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation>Sobor nemohl být otevřen.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation>Operace se souborem byla přerušena.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation>Vypršel časový limit.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation>Nastala neznámá chyba.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation>Soubor se nepodařilo odstranit.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation>Soubor se nepodařilo přejmenovat.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation>Pozice v souboru nemohla být změněna.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation>Nepodařilo se změnit velikost souboru.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation>Nepodařilo se přistoupit k souboru.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation>Soubor se nedá zkopírovat.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation>Nastala neznámá chyba.</translation>
    </message>
</context>
</TS>
